
******* ROUND 61	
use "data61.dta", clear
* data is Sorted by:  sector  state  region  stratum  sub_sample  sub_round  fsu  hg_sb sss hh_no  person_no

* -------------------------------------------------------------
* CLEANING THE DATA
* -------------------------------------------------------------

qui {
rename state state_old
gen state = state_old
move state state_old

replace state = 30 if state_old==25   // Daman diu => Goa
replace state = 23 if state_old==22   // Chhattisgarh => MP
replace state = 10 if state_old==20   // Jharkhand => Bihar
replace state = 9 if state_old==5     // Uttaranchal => UP 

label define state_lbl 28 "Andhra Pradesh" 18 "Assam" 10 "Bihar" 24 "Gujarat" 6 "Haryana" 2 "Himachal Pradesh" ///
1 "Jammu & Kashmir" 29 "Karnataka" 32 "Kerala" 23 "Madhya Pradesh" 27 "Maharashtra" 14 "Manipur" 17 "Meghalaya" ///
13 "Nagaland" 21 "Orissa" 3 "Punjab" 8 "Rajasthan" 11 "Sikkim" 33 "Tamil Nadu" 16 "Tripura" 9 "Uttar Pradesh" ///
19 "West Bengal" 35 "A & N Islands" 12 "Arunachal Pradesh" 4 "Chandigarh" 26 "Dadra & Nagar Haveli" 7 "Delhi" ///
30 "Goa" 31 "Lakshdweep" 15 "Mizoram" 34 "Pondicherry"
label values state state_lbl
}

generate zone=.
replace zone=1 if state=="Haryana":state_lbl|state=="Himachal Pradesh":state_lbl|state=="Jammu & Kashmir":state_lbl|state=="Punjab":state_lbl|state=="Delhi":state_lbl|state=="Chandigarh":state_lbl
replace zone=2 if state=="Assam":state_lbl|state=="Bihar":state_lbl|state=="Orissa":state_lbl|state=="West Bengal":state_lbl|state=="Tripura":state_lbl|state=="A & N Islands":state_lbl
replace zone=3 if state=="Madhya Pradesh":state_lbl|state=="Rajasthan":state_lbl|state=="Uttar Pradesh":state_lbl
replace zone=4 if state=="Manipur":state_lbl|state=="Meghalaya":state_lbl|state=="Nagaland":state_lbl|state=="Sikkim":state_lbl|state=="Mizoram":state_lbl|state=="Arunachal Pradesh":state_lbl
replace zone=5 if state=="Andhra Pradesh":state_lbl|state=="Karnataka":state_lbl|state=="Kerala":state_lbl|state=="Tamil Nadu":state_lbl|state=="Goa":state_lbl|state=="Lakshdweep":state_lbl|state=="Pondicherry":state_lbl
replace zone=6 if state=="Gujarat":state_lbl|state=="Maharashtra":state_lbl|state=="Dadra & Nagar Haveli":state_lbl

label define zone_lbl 1 "North" 2 "East" 3 "Central" 4 "North-East" 5 "South" 6 "West"
label values zone zone_lbl




// create hh-specific identifier
egen  hh_fsuno2=group( sector state region stratum sub_sample sub_round fsu hg_sb sss hh_no )

// create individual-specific identifier
egen  person_fsuno2=group( sector state region stratum sub_sample sub_round fsu hg_sb sss hh_no person_no)

// create individual/activity -specific identifier
egen  person_activity_fsuno2=group( sector state region stratum sub_sample sub_round fsu hg_sb sss hh_no person_no activity_no)


// report repeated inviduals: NOTE that there will be repeated individuals because for each individual we have several activities now
duplicates tag  person_activity_fsuno2, generate(person_activity_dupl)

// drop observations for which there are duplicates
drop if person_activity_dupl!=0


// Check if total number of days worked for each individual is great than 7
// this is to roughly drop the cases when hh head might be miscoded.
// want to drop hhs with more than one hh head, but is problematic b/c each person now has several activities, so wo;; have more than one obs per person

by person_fsuno2, sort: egen total_days_check=sum(total_days)
drop if total_days_check>7


// COMPUTE THE SIZE OF THE HH, B/C THE REPORTED SIZE IS MISLEADING SOMETIMES
egen hh_size2 = nvals(person_no), by(hh_fsuno2)
edit  fsu hh_no hh_size hh_size2 person_no reln_head sex age usual_nco68


// drop if there is no info on caste or miscoded info
drop if hh_group==. | hh_group==0 //Not in household group code

// CASTE IDENTIFIER: add backwards castes into nonSTSC category
ge hh_groupSCST2=1 if hh_group==1|hh_group==2
replace hh_groupSCST2=0 if hh_group==9|hh_group==3
label variable  hh_groupSCST2 "1-SCST, 0-non STSC"

// variable sex is Male=1, Female=2
label variable  sex "1-male, 2-female"
ta sex, gen(sex)

// variable sector is Rural=1, Urban=2
label variable  sector "1-rural, 2-urban"
ta sector, gen(sector)

// variable marital_status is currently_married=2, otherwise=1,3,4
drop if marital_status==0
label variable  marital_status "2-cur married, 1-never married 3-widower/divorced"
ta marital_status, gen(marital_status)


// CONSTRUCT CATEGORIES FOR EDUCATION
generate gen_edu2=.
replace  gen_edu2=1 if (gen_edu==1)
replace  gen_edu2=2 if (gen_edu==2|gen_edu==3|gen_edu==4|gen_edu==5)
replace  gen_edu2=3 if gen_edu==6
replace  gen_edu2=4 if gen_edu==7
replace  gen_edu2=5 if gen_edu>=8


// MULTIPLIERS
gen mul4=.
replace mul4=mlt_ss/100 if nss==nsc
replace mul4=mlt_ss/200 if nss!=nsc

//ENROLLMENT CODE
generate enrol_code61=.
replace enrol_code61=1 if (age<30)&(enrol_code==1|enrol_code==2|enrol_code==3|enrol_code==4|enrol_code==5|enrol_code==11|enrol_code==12|enrol_code==13|enrol_code==14|enrol_code==15) //asked only for age <30 in round 55 and 61
replace enrol_code61=1 if age>=30

//MPCE is total for the household, not in per capita terms. Divide by hhsize to get per capita values
ge mpce2=mpce/hh_size2
drop mpce
rename mpce2 mpce



* -------------------------------------------------------------
* CONSTRUCT WAGE DATA 
* -------------------------------------------------------------
// drop observations with negative occ. codes and not classified workers
egen usual_nco68_clean = sieve(usual_nco68), keep(numeric)
// drop observations with less than three characters
gen len = length(usual_nco68_clean)
drop if len==1|len==2
// convert string occupation code into a real number
generate  usual_nco68num=real(usual_nco68_clean)
format  usual_nco68num %03.0f


// do the same with weekly occupation codes
egen weekly_nco68_clean = sieve(weekly_nco68), keep(numeric)
gen len2 = length(weekly_nco68_clean)
drop if len2==1|len2==2
generate  weekly_nco68num=real(weekly_nco68_clean)
format  weekly_nco68num %03.0f



// wages are for weekly occupations only, and for different activities. 
// We extrapolate this wage info as follows:
// 1. use wages if weekly and usual occupations coincide
// 2. and individual is working in this occupation during majority of his week
// 3. wage is NOT equal to zero

by person_fsuno2, sort : egen main_act=max(total_days) 

gen wage_usual=.
replace wage_usual=wage_tot/main_act if wage_tot!=0 & main_act==total_days & weekly_nco68_clean==usual_nco68_clean

keep if main_act==total_days
* there may still be two observations for individuals that spent 3.5 days in main and secondary occupations; or 2 days in each of the three activities
* drop one without wage or the one indicated as secondary occupation

// report repeated inviduals: NOTE that there will be repeated individuals because for each individual we have several activities now
duplicates tag  person_fsuno2, generate(person_dupl)
ta person_dupl

// drop observations for which there are duplicates: three obs per person
drop if (person_dupl==2 & wage_usual==. & activity_no==1)
by  person_fsuno2, sort: egen activity_min=min(activity_no) if person_dupl==2
drop if (person_dupl==2 & activity_no!=activity_min & wage_usual==.)
drop if (person_dupl==2 & activity_no>activity_min)

// drop observations for which there are duplicates: two obs per person
drop activity_min
drop if (person_dupl==1 & wage_usual==. & activity_no==1)
by  person_fsuno2, sort: egen activity_min=min(activity_no) if person_dupl==1
drop if (person_dupl==1 & activity_no!=activity_min & wage_usual==.)
drop if (person_dupl==1 & activity_no>activity_min)


// check that no more duplicates remained
drop person_dupl
duplicates tag  person_fsuno2, generate(person_dupl)
ta person_dupl

// Check if there is miscoding of household head (more than one head)
gen temp = 1 if reln_head == 1 
by hh_fsuno2, sort: egen no_of_head_in_hh = total(temp)
drop temp
drop if no_of_head_in_hh != 1
drop no_of_head_in_hh


// Get the price deflators in
sort state_old sector
merge state_old sector using "deflators2_r61"
ta _merge
drop if _merge==2
drop _merge


// compute real wages and real mpce
ge rmpce = mpce/poverty_line2
ge rwage_usual = wage_usual/poverty_line2
rename mpce nmpce
rename wage_usual nwage_usual
rename rmpce mpce
rename rwage_usual wage_usual 


* -------------------------------------------------------------
* COUNT DAYS A WORKER IS EMPLOYED, UNEMPLOYED OR NOT-IN-LABOR FORCE
* -------------------------------------------------------------
//Classify Employed(E), Unemployed(UE) and Not in Labour Force(NLF)
//Find total days employed (based on daily status) in a week for each person
by person_fsuno2, sort: egen temp = total(total_days) if (activity_status >= 11 & activity_status <= 72)
by person_fsuno2, sort: egen days_e = mean(temp)
drop temp
//Total days unemployed
by person_fsuno2, sort: egen temp = total(total_days) if (activity_status ==81 | activity_status == 82)
by person_fsuno2, sort: egen days_ue = mean(temp)
drop temp
//Total days NLF
by person_fsuno2, sort: egen temp = total(total_days) if (activity_status >=91 & activity_status <= 98)
by person_fsuno2, sort: egen days_nlf = mean(temp)
drop temp
replace  days_e =0 if  days_e==.
replace  days_ue =0 if  days_ue==.
replace  days_nlf =0 if  days_nlf==.


* -------------------------------------------------------------
* LOWER DIGIT OCCUPATION CODES
* -------------------------------------------------------------

* generate 1-digit occupation codes
generate usual_nco68one=substr(usual_nco68_clean,1,1)
generate usual_nco68onenum=real(usual_nco68one)
format  usual_nco68onenum %01.0f

* create a 7-categories occupation code
generate usual_nco68onenum7=.
replace usual_nco68onenum7=usual_nco68onenum if usual_nco68onenum==2|usual_nco68onenum==3|usual_nco68onenum==4|usual_nco68onenum==5|usual_nco68onenum==6
replace usual_nco68onenum7=1 if usual_nco68onenum==0|usual_nco68onenum==1
replace usual_nco68onenum7=7 if usual_nco68onenum==7|usual_nco68onenum==8|usual_nco68onenum==9

* create a 3-categories occupation code
generate usual_nco68onenum3=.
replace usual_nco68onenum3=1 if usual_nco68onenum7==1|usual_nco68onenum7==2|usual_nco68onenum7==3
replace usual_nco68onenum3=2 if usual_nco68onenum7==4|usual_nco68onenum7==5|usual_nco68onenum7==7
replace usual_nco68onenum3=3 if usual_nco68onenum7==6



* -------------------------------------------------------------
* CONSTRUCT HH HEAD's DATA 
* -------------------------------------------------------------
* create a new variable with the head's occupation
by hh_fsuno2, sort: gen  head_occ= usual_nco68num if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_occ2= max(head_occ)
drop head_occ
rename head_occ2 head_occ
tostring head_occ, generate(head_occ_clean)


* 1-digit
by hh_fsuno2, sort: gen  head_occone= usual_nco68onenum if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_occone2= max(head_occone)
drop head_occone
rename head_occone2 head_occone
tostring head_occone, generate(head_occone_clean)

* 7-categories occupation code
by hh_fsuno2, sort: gen  head_occone7= usual_nco68onenum7 if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_occone72= max(head_occone7)
drop head_occone7
rename head_occone72 head_occone7
tostring head_occone7, generate(head_occone7_clean)

* 3-categories occupation code
by hh_fsuno2, sort: gen  head_occone3= usual_nco68onenum3 if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_occone32= max(head_occone3)
drop head_occone3
rename head_occone32 head_occone3
tostring head_occone3, generate(head_occone3_clean)




*				     and head's education
by hh_fsuno2, sort: gen  head_edu= gen_edu2 if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_edu2= max(head_edu)
drop head_edu
rename head_edu2 head_edu

*				     and head's sex
by hh_fsuno2, sort: gen  head_sex= sex if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_sex2= max(head_sex)
drop head_sex
rename head_sex2 head_sex

*				     and hh head's spouse education
by hh_fsuno2, sort: gen  mom_edu=gen_edu2 if (reln_head==2&age>=16)
by hh_fsuno2, sort: egen mom_edu2= max(mom_edu)
drop mom_edu
rename mom_edu2 mom_edu

*				     and hh head's wage
by hh_fsuno2, sort: gen  wage_head = wage_usual if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen wage_head2 = max(wage_head)
drop wage_head
rename wage_head2 wage_head

*				     and hh head's age 
by hh_fsuno2, sort: gen  head_age= age if (reln_head==1&age>=16)
by hh_fsuno2, sort: egen head_age2 = max(head_age)
drop head_age
rename head_age2 head_age


****** prepare data for merging across rounds
gen round = 61
move round sector
compress
sort round sector state  region  stratum  sub_sample  sub_round  fsu  hg_sb sss hh_no person_no reln_head

save "data61_clean", replace
