// ***************************************************************************************

// THIS DO FILE CONTAINS STATA COMMANDS TO REPLICATE THE RESULTS IN 
/// HNATKOVSKA, LAHIRI, PAUL (2011) paper "CASTES AND LABOR MOBILITY"

// please cite as 
// Hnatkovska, Viktoria, Amartya Lahiri, and Sourabh B. Paul (2011) "Castes and Labor Mobility," American Economic Journal: Applied Economics, forthcoming

// USE THIS FILE TO OBTAIN ALL TABLES AND FIGURES IN THE TEXT
// EXCEPT FOR TABLES 6 AND 8, DO FILE FOR WHICH IS 20110156-TABLES6and8.do

*************************************************************************************** //


clear
set mem 2g
set matsize 800

global wk_dir c:/data10/caste_mobility/stata/AEJ    	//Define the working director
global data_dir c:/data10/caste_mobility/stata/new




cd "${wk_dir}"
use "${data_dir}/tempAll_clean", clear

* -------------------------------------------------------------- *
* Generate years of education
* -------------------------------------------------------------- *
gen edu_year = . 
replace edu_year = 0 if gen_edu >= 1 & gen_edu <= 4 & (round == 50 | round == 55 | round ==  61)  //No formal schooling
replace edu_year =  2 if gen_edu == 5 & (round == 50 | round == 55 | round ==  61) //Schooling below primary
replace edu_year =  5 if gen_edu == 6 & (round == 50 | round == 55 | round ==  61) //Primary
replace edu_year =  8 if gen_edu == 7 & (round == 50 | round == 55 | round ==  61) //Middle
replace edu_year =  10 if gen_edu == 8 & (round == 50 | round == 55 | round ==  61) //Secondary
replace edu_year =  10 if (gen_edu == 9 & (round == 50 | round == 55)) | (gen_edu == 10 & round == 61) //No additional years for higher secondar, since some rounds do not have this.

replace edu_year =  16 if (gen_edu == 10 | gen_edu==11 | gen_edu==12) & (round == 50 | round == 55) //Graduate degree in tech, eng, med, agri (4 years course). It is in tech_edu for 61 round.
replace edu_year =  15 if (gen_edu == 13) & (round == 50 | round == 55) //Graduate degree in all other subjects

replace edu_year =  10 if gen_edu == 11 & round == 61 //No additional years for post-secondary diploma/certificate course (not in technical stream) since other rounds do not have this.
replace edu_year =  15 if (gen_edu == 12 | gen_edu == 13) & round == 61 //No additional years for post-graduate degree since other rounds do not have this

replace edu_year = 0 if gen_edu <=1 & (round == 38 | round == 43)
replace edu_year = 2 if gen_edu == 2 & (round == 38 | round == 43)
replace edu_year = 5 if gen_edu == 3 & (round == 38 | round == 43)
replace edu_year = 8 if gen_edu == 4 & (round == 38 | round == 43)
replace edu_year = 10 if gen_edu == 5 & (round == 38 | round == 43)
replace edu_year = 16 if (gen_edu ==6 | gen_edu ==7 | gen_edu ==8) & (round == 38 | round == 43)
replace edu_year = 15 if (gen_edu ==9) & (round == 38 | round == 43)


//updating edu_year for technical education  

replace edu_year = edu_year + 1 if round == 50 & (tech_edu == 2 | tech_edu == 5 | tech_edu == 9)
replace edu_year = edu_year + 3 if round == 50 & tech_edu == 3
replace edu_year = edu_year + 2 if round == 50 & tech_edu == 4
replace edu_year = edu_year + 1 if round == 55 & (tech_edu == 3 | tech_edu == 6 | tech_edu == 9)
replace edu_year = edu_year + 3 if round == 55 & tech_edu == 4
replace edu_year = edu_year + 2 if round == 55 & tech_edu == 5
replace edu_year = edu_year + 4 if round == 55 & tech_edu == 2 & gen_edu ==9 
replace edu_year = edu_year + 4 if round == 61 & tech_edu == 2 & gen_edu ==10 
replace edu_year = edu_year + 1 if round == 61 & (tech_edu == 3 | tech_edu ==6 | tech_edu == 7)
replace edu_year = edu_year + 3 if round == 61 & tech_edu == 4
replace edu_year = edu_year + 2 if round == 61 & tech_edu == 5
replace edu_year = edu_year + 1 if round == 61 & (tech_edu >= 8 & tech_edu<=12) //need to drop ?? - since other rounds do not have this category

replace edu_year = edu_year + 1 if round == 38 & (tech_edu >= 10 & tech_edu<=14)  // need to update ?
replace edu_year = edu_year + 1 if round == 43 & (tech_edu >= 1 & tech_edu <=5)		// need to update ?
compress edu_year	


* -------------------------------------------------------------- *
* 				Individual sample selection
* -------------------------------------------------------------- *

// keep if the age is between 16 and 65
generate select_age = 0
replace  select_age = 1 if (age >= 16 & age<= 65) 
ta round select_age


// keep if occupation data is not missing
generate select_occ = 0
replace  select_occ = 1 if usual_nco68_clean!=""
ta round select_occ


// keep if not currently enrolled in education institution
generate select_enroll = 0
replace  select_enroll = 1 if (enrol_code38==1 | enrol_code43==1 | enrol_code50==1 | enrol_code55==1 | enrol_code61==1)
ta round select_enroll


//Consider only employed based on daily status (weighted sum over 7 days)
generate select_ft = 0
replace  select_ft = 1 if days_e>=2.5
ta round select_ft
ta round if select_enroll==1&select_ft==1


// keep if males
generate select_sex = 0
replace  select_sex = 1 if sex==1
ta round select_sex


// keep if wage info is non-missing
generate select_wage = 0
replace  select_wage = 1 if wage_usual!=.
ta round select_wage


// keep if education info is non-missing
generate select_edu = 0
replace  select_edu = 1 if gen_edu2!=.
ta round select_edu

//keep if household head is male
generate select_headsex = 0
replace select_headsex = 1 if head_sex==1
ta round select_headsex
compress


* -------------------------------------------------------------- *
* Replication of our sample restrictions
* -------------------------------------------------------------- *

// ***** INDIVIDUAL SAMPLE, YOUNG
gen overall_smplic=0
*Consider male headed households only
replace overall_smplic = 1 if select_headsex==1 & select_age==1 & select_occ==1 & select_enroll==1 & select_ft==1 & select_edu==1  & (age>=16 & age<=40)
ta round overall_smplic

gen wage_smplic = 0
replace wage_smplic = 1 if overall_smplic == 1 & select_wage==1 
ta round wage_smplic


// ***** INDIVIDUAL SAMPLE, OLD
gen overall_smplip=0
*Consider male headed households only
replace overall_smplip = 1 if select_headsex==1 & select_age==1 & select_occ==1 & select_enroll==1 & select_ft==1 & select_edu==1 & (age>=41 & age<=65)
ta round overall_smplip

gen wage_smplip = 0
replace wage_smplip = 1 if overall_smplip == 1 & select_wage==1 
ta round wage_smplip


* -------------------------------------------------------------- *
* GET MORE DATA IN AND DO SOME TRANSFORMATIONS
* -------------------------------------------------------------- *

// add reservation quotas numbers
sort round state_old
merge round state_old using "${data_dir}/quotas"
ta _merge
drop _merge
ge quota_scst=sc+st

// generate education dummies
ta gen_edu2, generate (edu_dum)
compress


label drop state_lbl
label define state_lbl 28 "Andhra Pradesh" 18 "Assam" 10 "Bihar" 24 "Gujarat" 6 "Haryana" 2 "Himachal Pradesh" ///
1 "Jammu & Kashmir" 29 "Karnataka" 32 "Kerala" 23 "Madhya Pradesh" 27 "Maharashtra" 14 "Manipur" 17 "Meghalaya" ///
13 "Nagaland" 21 "Orissa" 3 "Punjab" 8 "Rajasthan" 11 "Sikkim" 33 "Tamil Nadu" 16 "Tripura" 9 "Uttar Pradesh" ///
19 "West Bengal" 35 "A & N Islands" 12 "Arunachal Pradesh" 4 "Chandigarh" 26 "Dadra & Nagar Haveli" 7 "Delhi" ///
30 "Goa" 31 "Lakshdweep" 15 "Mizoram" 34 "Pondicherry"
label values state state_lbl

compress

// generate zone dummies
generate zone=.
replace zone=1 if state=="Haryana":state_lbl|state=="Himachal Pradesh":state_lbl|state=="Jammu & Kashmir":state_lbl|state=="Punjab":state_lbl|state=="Delhi":state_lbl|state=="Chandigarh":state_lbl
replace zone=2 if state=="Assam":state_lbl|state=="Bihar":state_lbl|state=="Orissa":state_lbl|state=="West Bengal":state_lbl|state=="Tripura":state_lbl|state=="A & N Islands":state_lbl
replace zone=3 if state=="Madhya Pradesh":state_lbl|state=="Rajasthan":state_lbl|state=="Uttar Pradesh":state_lbl
replace zone=4 if state=="Manipur":state_lbl|state=="Meghalaya":state_lbl|state=="Nagaland":state_lbl|state=="Sikkim":state_lbl|state=="Mizoram":state_lbl|state=="Arunachal Pradesh":state_lbl
replace zone=5 if state=="Andhra Pradesh":state_lbl|state=="Karnataka":state_lbl|state=="Kerala":state_lbl|state=="Tamil Nadu":state_lbl|state=="Goa":state_lbl|state=="Lakshdweep":state_lbl|state=="Pondicherry":state_lbl
replace zone=6 if state=="Gujarat":state_lbl|state=="Maharashtra":state_lbl|state=="Dadra & Nagar Haveli":state_lbl
compress

label define zone_lbl 1 "North" 2 "East" 3 "Central" 4 "North-East" 5 "South" 6 "West"
label values zone zone_lbl

ta zone, generate(zone_dum)
compress







*============================================================
* FIGURE 1: LABOR FORCE PARTICIPATION AND EMPLOYMENT GAPS
*============================================================
//Define employed, unemployed, casual worker, self-employed, labour force participation based on WEEKLY STATUS (7 days) 
gen employed = 0 //Employed
replace employed = 1 if (round==38) & (weekly_status==1 | weekly_status==2 | weekly_status==3 | weekly_status==4 )

replace employed = 1 if ( weekly_status==11 | weekly_status==21 | weekly_status==31 /// 
	| weekly_status==41 | weekly_status==51 | weekly_status==61 | weekly_status==71)
replace employed = 1 if (round==50 | round==55 | round==61) & /// 
	( weekly_status==12 | weekly_status==62 | weekly_status==72 )
replace employed = 1 if (round==43) & (weekly_status==62 | weekly_status==72 )

	
gen unemployed = 0  // Unemployed
replace unemployed = 1 if (weekly_status==81 | weekly_status==82)

gen casual_worker = 0
replace casual_worker = 1 if (weekly_status==41 | weekly_status==51)
replace casual_worker = 1 if (round==61) & (weekly_status==42)

gen self_employed = 0 //Self-employed
replace self_employed = 1 if (weekly_status==11 | weekly_status==21)
replace self_employed = 1 if (round==50 | round == 55 | round == 61) & (weekly_status==12)
	
	
gen lab_force = 0  //Labour force
replace lab_force = 1 if (employed==1 | unemployed==1)

gen ft_worker = 0 //Full time worker defined as total days of work >=2.5 in a week
replace ft_worker =1 if select_ft==1 

gen pt_worker = 0 //Part time worker defined as total days of work <2.5 in a week
replace pt_worker =1 if days_e<2.5

//Create sample without restricting full time workers, has occupation, etc (broader sample that includes not-in-labor-force)
gen lfp_smplic = 0
replace lfp_smplic = 1 if select_headsex==1 & select_age==1 & select_enroll==1 & select_edu==1  & (age>=16 & age<=40)
gen lfp_smplip = 0
replace lfp_smplip = 1 if select_headsex==1 & select_age==1 & select_enroll==1 & select_edu==1  & (age>=41 & age<=65)

* compute shares for the SC/STs and non-SC/STs as identified by hh_groupSCST2 variable
mat LFP = J(1,2,.)
mat EMP = J(1,2,.)
mat FULL = J(1,2,.)
mat PART = J(1,2,.)
mat SELF = J(1,2,.)

levelsof round, local(round)
foreach r of local round{
	mean  lab_force [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1) & round==`r', over(hh_groupSCST2) 
	mat LFP = LFP\e(b)
	mean  employed [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1) & lab_force==1 & round==`r', over(hh_groupSCST2) 
	mat EMP = EMP\e(b)
	mean  ft_worker [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1 ) & employed==1 & round==`r', over(hh_groupSCST2)
	mat FULL = FULL\e(b)
	mean  pt_worker [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1 ) & employed==1 & round==`r', over(hh_groupSCST2)
	mat PART = PART\e(b)
	mean  self_employed [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1) & employed==1 & round==`r', over(hh_groupSCST2) 
	mat SELF = SELF\e(b)
}

svmat LFP
svmat EMP
svmat FULL
svmat PART
svmat SELF

gen LFP_gap = LFP1/LFP2
gen EMP_gap = EMP1/EMP2
gen FULL_gap = FULL1/FULL2
gen PART_gap = PART1/PART2
gen SELF_gap = SELF1/SELF2

* ----------------------------- FIGURE 1. 
mat rou = .\38\42\50\55\61
svmat rou
label define rou_lbl 38 "1983" 43 "1987-88" 50 "1993-94" 55 "1999-00" 61 "2004-05"
label values rou1 rou_lbl

twoway (scatter LFP_gap rou1, lpattern("l") lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter EMP_gap rou1, lpattern("l.") lwidth(thick) c(l) ms(D) msize(large))  ///
    || (scatter FULL_gap rou1, lpattern(".") lwidth(thick) c(l) ms(T) msize(large))  ///
    || (scatter PART_gap rou1, lpattern("_") lwidth(thick) c(l) ms(O) msize(large)) ,  ///
    	xtitle(" ") ytitle("") title("Relative labor market gaps", size(huge)) subtitle("") ///
		xscale(range(37 62)) xlabel(38 43 50 55 61, valuelabel labs(medium) ) ///
    	ylabel(0.6(0.1)1.1, labs(medium)) ytic(0.6(0.1)1.1) ///
    	legend(col(4) size(medium)) ///
    	legend(on order(1 "lfp" 2 "employed" 3 "full-time" 4 "part-time" )) ///
     	saving(lfp-gap-all, replace)
*graph export lfp-gap-all.eps, as(eps) replace


*============================================================
* TABLE 1: SAMPLE SUMMARY STATISTICS
*============================================================

* -------------------- (a) Individual characteristics

* INDIVIDUAL CHARACTERISTICS - NON-SCSTs
mat A = J(1,5,.)
levelsof round, local(round)
foreach r of local round{
	mean age edu_year sex1 marital_status2 [pw=mul4] if (overall_smplic==1|overall_smplip==1) & hh_groupSCST2==0 & round==`r'
	mat A = A\e(b)
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
	
}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat SAMPLE_ALL_NONSCST = A //Sample mean for non-SCST
mat list SAMPLE_ALL_NONSCST

* INDIVIDUAL CHARACTERISTICS - SC/STs
mat A = J(1,5,.)
levelsof round, local(round)
foreach r of local round{
	mean age edu_year sex1 marital_status2 [pw=mul4] if (overall_smplic==1|overall_smplip==1) & hh_groupSCST2==1 & round==`r'
	mat A = A\e(b)
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se 
mat SAMPLE_ALL_SCST = A //Sample mean for SCST
mat list SAMPLE_ALL_SCST


* -------------------- (b) Household characteristics

* creating household level multiplier that reflects size of population
gen hh_mul4 = mul4*hh_size2 
gen mpced = mpce/30

* HOUSEHOLDS CHARACTERISTICS - NON-SCST
mat A = J(1,7,.)
levelsof round, local(round)
foreach r of local round{
	mean sector1 hh_size2 [pw=hh_mul4] if reln_head==1 & (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==0
	mat A = A\e(b)
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
	}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat HHOLD_NON = A  
mat list HHOLD_NON

* HOUSEHOLDS CHARACTERISTICS - SCST
mat A = J(1,7,.)
levelsof round, local(round)
foreach r of local round{
	mean sector1 hh_size2 [pw=hh_mul4] if reln_head==1 & (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==1
	mat A = A\e(b)
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
	}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat HHOLD_SCST = A  
mat list HHOLD_SCST


**************************************************************************************************************************
**************************************************************************************************************************
*****************				EDUCATION			**********************************************************
**************************************************************************************************************************
**************************************************************************************************************************

* -------------------------------------------------------------- 
* TABLE 2: EDUCATION GAP: YEARS OF SCHOOLING
* -------------------------------------------------------------- 

* YEARS OF EDUCATION - OVERALL, SC/ST, NON-SC/ST
mat B = J(1,1,.)
mat A = J(1,2,.)

levelsof round, local(round)
foreach r of local round{
	mean  edu_year [pw=mul4] if (overall_smplic==1 | overall_smplip==1) & round==`r'
	mat B = B\e(b)
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat B = B\E

	mean  edu_year [pw=mul4] if (overall_smplic==1 | overall_smplip==1) & round==`r', over(hh_groupSCST2) 
	mat A = A\e(b)
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
}
matrix rownames B = blank 38 se 43 se 50 se 55 se 61 se
mat CONV_EDUY = B 
mat list CONV_EDUY

matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat CONV_EDUY_C = A 
mat list CONV_EDUY_C


* -------------------------------------------------------------- 
* FIGURE 2: EDUCATION GAPS BY BIRTH COHORTS
* -------------------------------------------------------------- 
// generate birth cohort  
gen birth_cohort =.  

 // birth 1982 - 1988   
replace birth_cohort = 10 if ((age>=17 & age <=23) & (round == 61)) 

  // birth 1975 - 1981   
replace birth_cohort = 9 if ((age>=19 & age <=25) &(round == 55)) | ((age>=24 & age <=30) & (round == 61)) 

  // birth 1968 - 1974   
replace birth_cohort = 8 if ((age>=20 & age <=26) & (round == 50)) | ((age>=26 & age <=32) &(round == 55)) | ((age>=31 & age <=37) & (round == 61)) 

  // birth 1961 - 1967   
replace birth_cohort = 7 if ((age >= 16 & age<=22) & (round == 38)) | ((age>=21 & age <=27) & (round == 43)) | ((age>=27 & age <=33) & (round == 50)) | ((age>=33 & age <=39) &(round == 55)) | ((age>=38 & age <=44) & (round == 61)) 
 
  // birth 1954 - 1960   
replace birth_cohort = 6 if ((age >= 23 & age<=29) & (round == 38)) | ((age>=28 & age <=34) & (round == 43)) | ((age>=34 & age <=40) & (round == 50)) | ((age>=40 & age <=46) &(round == 55)) | ((age>=45 & age <=51) & (round == 61)) 

  // birth 1947 - 1953   
replace birth_cohort = 5 if ((age >= 30 & age<=36) & (round == 38)) | ((age>=35 & age <=41) & (round == 43)) | ((age>=41 & age <=47) & (round == 50)) | ((age>=47 & age <=53)&(round == 55)) | ((age>=52 & age <=58) & (round == 61)) 

  // birth 1940 - 1946   
replace birth_cohort = 4 if ((age >= 37 & age<=43) & (round == 38)) | ((age>=42 & age <=48) & (round == 43)) | ((age>=48 & age <=54) & (round == 50)) | ((age>=54 & age <=60) &(round == 55)) | ((age>=59 & age <=65) &(round == 61)) 

  // birth 1933 - 1939   
replace birth_cohort = 3 if ((age >= 44 & age<=50) & (round == 38)) | ((age>=49 & age <=55) & (round == 43)) | ((age>=55 & age <=61) & (round == 50)) | ((age>=61 & age <=65) & (round == 55)) 

  // birth 1926 - 1932   
replace birth_cohort = 2 if ((age >= 51 & age<=57) & (round == 38)) | ((age>=56 & age <=62) & (round == 43)) 

  // birth 1919 - 1925   
replace birth_cohort = 1 if ((age >= 58 & age<=64) & (round == 38)) 



* OVERALL
mat Aedubirth = J(1,21,.) //mean education years
mat A = J(1,21,.) //mean education years 
levelsof round, local(round)
qui foreach r of local round{
	mat A1 = J(1,1,.)
	mat A2 = J(1,1,.)

	forvalues j = 0/1{
		forvalues i = 1/10{
			count if (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==`j' & birth_cohort==`i'
			if(r(N)>10){
				mean edu_year [pw=mul4] if (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==`j' & birth_cohort==`i'
				mat A1 = A1,e(b)
				mat E1 = vecdiag(e(V))
				matmap E1 E1, m(sqrt(@))
				mat A2 = A2,E1
			}
			else {
				mat A1 = A1,.
				mat A2 = A2,.
			}
		}
	}
	mat A = A\A1\A2
	mat Aedubirth = Aedubirth\A1
}
mat rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat colnames A = blank "N1919-1925" "N1926-1932" "N1933-1939" "N1940-1946" "N1947-1953" "N1954-1960" "N1961-1967" "N1968-1974" "N1975-1981" "N1982-1988" ///
		       "S1919-1925" "S1926-1932" "S1933-1939" "S1940-1946" "S1947-1953" "S1954-1960" "S1961-1967" "S1968-1974" "S1975-1981" "S1982-1988"
mat list A //Mean edu across birth cohort

* RURAL
mat AedubirthR = J(1,21,.) //mean education years
mat A = J(1,21,.) //mean education years 
levelsof round, local(round)
qui foreach r of local round{
	mat A1 = J(1,1,.)
	mat A2 = J(1,1,.)

	forvalues j = 0/1{
		forvalues i = 1/10{
			count if (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==`j' & birth_cohort==`i' & sector==1
			if(r(N)>10){
				mean edu_year [pw=mul4] if (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==`j' & birth_cohort==`i' & sector==1
				mat A1 = A1,e(b)
				mat E1 = vecdiag(e(V))
				matmap E1 E1, m(sqrt(@))
				mat A2 = A2,E1
			}
			else {
				mat A1 = A1,.
				mat A2 = A2,.
			}
		}
	}
	mat A = A\A1\A2
	mat AedubirthR = AedubirthR\A1
}
mat rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat colnames A = blank "N1919-1925" "N1926-1932" "N1933-1939" "N1940-1946" "N1947-1953" "N1954-1960" "N1961-1967" "N1968-1974" "N1975-1981" "N1982-1988" ///
		       "S1919-1925" "S1926-1932" "S1933-1939" "S1940-1946" "S1947-1953" "S1954-1960" "S1961-1967" "S1968-1974" "S1975-1981" "S1982-1988"


* URBAN
mat AedubirthU = J(1,21,.) //mean education years
mat A = J(1,21,.) //mean education years 
levelsof round, local(round)
qui foreach r of local round{
	mat A1 = J(1,1,.)
	mat A2 = J(1,1,.)

	forvalues j = 0/1{
		forvalues i = 1/10{
			count if (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==`j' & birth_cohort==`i' & sector==2
			if(r(N)>10){
				mean edu_year [pw=mul4] if (overall_smplic==1 | overall_smplip==1) & round==`r' & hh_groupSCST2==`j' & birth_cohort==`i' & sector==2
				mat A1 = A1,e(b)
				mat E1 = vecdiag(e(V))
				matmap E1 E1, m(sqrt(@))
				mat A2 = A2,E1
			}
			else {
				mat A1 = A1,.
				mat A2 = A2,.
			}
		}
	}
	mat A = A\A1\A2
	mat AedubirthU = AedubirthU\A1
}
mat rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat colnames A = blank "N1919-1925" "N1926-1932" "N1933-1939" "N1940-1946" "N1947-1953" "N1954-1960" "N1961-1967" "N1968-1974" "N1975-1981" "N1982-1988" ///
		       "S1919-1925" "S1926-1932" "S1933-1939" "S1940-1946" "S1947-1953" "S1954-1960" "S1961-1967" "S1968-1974" "S1975-1981" "S1982-1988"
	   
			   
* PLOTTING FIGURE 2. Education gaps by birth cohorts

******************************************** OVERALL
svmat Aedubirth
gen Aedubirthgap1  = Aedubirth2/Aedubirth12
gen Aedubirthgap2  = Aedubirth3/Aedubirth13
gen Aedubirthgap3  = Aedubirth4/Aedubirth14
gen Aedubirthgap4  = Aedubirth5/Aedubirth15
gen Aedubirthgap5  = Aedubirth6/Aedubirth16
gen Aedubirthgap6  = Aedubirth7/Aedubirth17
gen Aedubirthgap7  = Aedubirth8/Aedubirth18
gen Aedubirthgap8  = Aedubirth9/Aedubirth19
gen Aedubirthgap9  = Aedubirth10/Aedubirth20
gen Aedubirthgap10 = Aedubirth11/Aedubirth21
drop Aedubirth1-Aedubirth21


twoway (scatter Aedubirthgap1 rou1, lpattern("l") lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter Aedubirthgap2 rou1, lpattern("l.") lwidth(thick) c(l) ms(D) msize(large)) ///
    || (scatter Aedubirthgap3 rou1, lpattern(".") lwidth(thick) c(l) ms(T) msize(large)) ///
    || (scatter Aedubirthgap4 rou1, lpattern("-") lwidth(thick) c(l) ms(O) msize(large)) ///
    || (scatter Aedubirthgap5 rou1, lpattern(".-") lwidth(thick) c(l) ms(+) msize(large)) ///
    || (scatter Aedubirthgap6 rou1, lpattern("...-") lwidth(thick) c(l) ms(Sh) msize(large)) ///
    || (scatter Aedubirthgap7 rou1, lpattern("--..") lwidth(thick) c(l) ms(Dh) msize(large)) ///
    || (scatter Aedubirthgap8 rou1, lpattern("_") lwidth(thick) c(l) ms(Th) msize(large)) ///
    || (scatter Aedubirthgap9 rou1, lpattern("_..") lwidth(thick) c(l) ms(Oh) msize(large)) ///
    || (scatter Aedubirthgap10 rou1, lpattern(".--") lwidth(thick) c(l) ms(x) msize(large)),  ///
    	xtitle(" ") ytitle("") title("overall", size(huge)) subtitle("") ///
		xscale(range(0.9 5.1)) xlabel(, valuelabel labs(medium) ) ///
    	ylabel(1.5(0.5)3.5, labs(medium)) ytic(1.5(0.5)3.5) ///
    	legend(col(5) size(medium))  ///
    	legend(on order(1 "1919-25" 2 "1926-32" 3 "1933-39" 4 "1940-46" 5 "1947-53" 6 "1954-60" 7 "1961-67" 8 "1968-74" 9 "1975-81" 10 "1982-88")) ///
    	saving(edu-birth, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\edu-birth.eps, as(eps) replace

drop Aedubirthgap1-Aedubirthgap10

*********************************************** RURAL
svmat AedubirthR
gen AedubirthgapR1  = AedubirthR2/AedubirthR12
gen AedubirthgapR2  = AedubirthR3/AedubirthR13
gen AedubirthgapR3  = AedubirthR4/AedubirthR14
gen AedubirthgapR4  = AedubirthR5/AedubirthR15
gen AedubirthgapR5  = AedubirthR6/AedubirthR16
gen AedubirthgapR6  = AedubirthR7/AedubirthR17
gen AedubirthgapR7  = AedubirthR8/AedubirthR18
gen AedubirthgapR8  = AedubirthR9/AedubirthR19
gen AedubirthgapR9  = AedubirthR10/AedubirthR20
gen AedubirthgapR10 = AedubirthR11/AedubirthR21
drop AedubirthR1-AedubirthR21

twoway (scatter AedubirthgapR1 rou1, lpattern("l") lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter AedubirthgapR2 rou1, lpattern("l.") lwidth(thick) c(l) ms(D) msize(large)) ///
    || (scatter AedubirthgapR3 rou1, lpattern(".") lwidth(thick) c(l) ms(T) msize(large)) ///
    || (scatter AedubirthgapR4 rou1, lpattern("-") lwidth(thick) c(l) ms(O) msize(large)) ///
    || (scatter AedubirthgapR5 rou1, lpattern(".-") lwidth(thick) c(l) ms(+) msize(large)) ///
    || (scatter AedubirthgapR6 rou1, lpattern("...-") lwidth(thick) c(l) ms(Sh) msize(large)) ///
    || (scatter AedubirthgapR7 rou1, lpattern("--..") lwidth(thick) c(l) ms(Dh) msize(large)) ///
    || (scatter AedubirthgapR8 rou1, lpattern("_") lwidth(thick) c(l) ms(Th) msize(large)) ///
    || (scatter AedubirthgapR9 rou1, lpattern("_..") lwidth(thick) c(l) ms(Oh) msize(large)) ///
    || (scatter AedubirthgapR10 rou1, lpattern(".--") lwidth(thick) c(l) ms(x) msize(large)),  ///
    	xtitle(" ") ytitle("") title("rural", size(huge)) subtitle("") ///
		xscale(range(0.9 5.1)) xlabel(, valuelabel labs(medium) ) ///
    	ylabel(1.5(0.5)3.5, labs(medium)) ytic(1.5(0.5)3.5) ///
    	legend(col(5) size(medium))  ///
    	legend(on order(1 "1919-25" 2 "1926-32" 3 "1933-39" 4 "1940-46" 5 "1947-53" 6 "1954-60" 7 "1961-67" 8 "1968-74" 9 "1975-81" 10 "1982-88")) ///
    	saving(edu-birthRural, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\edu-birthRural.eps, as(eps) replace

drop AedubirthgapR1-AedubirthgapR10

*********************************************** URBAN
svmat AedubirthU
gen AedubirthgapU1  = AedubirthU2/AedubirthU12
gen AedubirthgapU2  = AedubirthU3/AedubirthU13
gen AedubirthgapU3  = AedubirthU4/AedubirthU14
gen AedubirthgapU4  = AedubirthU5/AedubirthU15
gen AedubirthgapU5  = AedubirthU6/AedubirthU16
gen AedubirthgapU6  = AedubirthU7/AedubirthU17
gen AedubirthgapU7  = AedubirthU8/AedubirthU18
gen AedubirthgapU8  = AedubirthU9/AedubirthU19
gen AedubirthgapU9  = AedubirthU10/AedubirthU20
gen AedubirthgapU10 = AedubirthU11/AedubirthU21
drop AedubirthU1-AedubirthU21

twoway (scatter AedubirthgapU1 rou1, lpattern("l") lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter AedubirthgapU2 rou1, lpattern("l.") lwidth(thick) c(l) ms(D) msize(large)) ///
    || (scatter AedubirthgapU3 rou1, lpattern(".") lwidth(thick) c(l) ms(T) msize(large)) ///
    || (scatter AedubirthgapU4 rou1, lpattern("-") lwidth(thick) c(l) ms(O) msize(large)) ///
    || (scatter AedubirthgapU5 rou1, lpattern(".-") lwidth(thick) c(l) ms(+) msize(large)) ///
    || (scatter AedubirthgapU6 rou1, lpattern("...-") lwidth(thick) c(l) ms(Sh) msize(large)) ///
    || (scatter AedubirthgapU7 rou1, lpattern("--..") lwidth(thick) c(l) ms(Dh) msize(large)) ///
    || (scatter AedubirthgapU8 rou1, lpattern("_") lwidth(thick) c(l) ms(Th) msize(large)) ///
    || (scatter AedubirthgapU9 rou1, lpattern("_..") lwidth(thick) c(l) ms(Oh) msize(large)) ///
    || (scatter AedubirthgapU10 rou1, lpattern(".--") lwidth(thick) c(l) ms(x) msize(large)),  ///
    	xtitle(" ") ytitle("") title("urban", size(huge)) subtitle("") ///
		xscale(range(0.9 5.1)) xlabel(, valuelabel labs(medium) ) ///
    	ylabel(1.5(0.5)3.5, labs(medium)) ytic(1.5(0.5)3.5) ///
    	legend(col(5) size(medium))  ///
    	legend(on order(1 "1919-25" 2 "1926-32" 3 "1933-39" 4 "1940-46" 5 "1947-53" 6 "1954-60" 7 "1961-67" 8 "1968-74" 9 "1975-81" 10 "1982-88")) ///
    	saving(edu-birthUrban, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\edu-birthUrban.eps, as(eps) replace

drop AedubirthgapU1-AedubirthgapU10

* -------------------------------------------------------------- 
* FIGURE 3: EDUCATION DISTRIBUTION
* -------------------------------------------------------------- 

* NON-SC/STs 
mat A = J(1,5,.)
mat Anonscst = J(1,5,.)
levelsof round, local(round)
foreach r of local round{
	proportion gen_edu2 if (overall_smplic==1|overall_smplip==1) & round==`r' & hh_groupSCST2==0
	mat A = A\e(b)*100
	mat Anonscst = Anonscst\e(b)*100
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E

}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat WORKFORCE_ALL_EDU_NONSCST = A  
mat list WORKFORCE_ALL_EDU_NONSCST

* SC/STs 
mat A = J(1,5,.)
mat Ascst = J(1,5,.)
levelsof round, local(round)
foreach r of local round{
	proportion gen_edu2 if (overall_smplic==1|overall_smplip==1) & round==`r' & hh_groupSCST2==1
	mat A = A\e(b)*100
	mat Ascst = Ascst\e(b)*100
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se
mat WORKFORCE_ALL_EDU_SCST = A  //Distribution of work force across education  for YOUNG - SCST
mat list WORKFORCE_ALL_EDU_SCST


* PLOTTING FIGURE 3a. DISTRIBUTION OF WORKFORCE ACROSS EDUCATION
*   create a vector of round values for plotting
matrix rou = .\1\2\3\4\5
mat rou=rou\rou
svmat rou
label define rou1_lbl 1 "1983" 2 "1987-88" 3 "1993-94" 4 "1999-00" 5 "2004-05"
label values rou1 rou1_lbl
  
 
* combine non-SC/STs and SC/STs
mat Aall=Anonscst\Ascst
svmat Aall
label variable Aall1 "Edu1"
label variable Aall2 "Edu2"
label variable Aall3 "Edu3"
label variable Aall4 "Edu4"
label variable Aall5 "Edu5"

gen scst_divide=.
replace scst_divide=0 in 1/6
replace scst_divide=1 in 7/12
label define scst_lbl 0 "Non-SC/ST" 1 "SC/ST"
label values scst_divide scst_lbl

graph bar (asis) Aall1 Aall2 Aall3 Aall4 Aall5, over(rou1, label(alternate labsize(medium))) over(scst_divide, label(labsize(large))) ///  
		 stack percent     ytitle(" ") ///
		 title("Distribution of workforce across edu", span ) ///
		 legend(col(5) size(medium)) ///
		 saving(distr_all, replace) scheme(sj)
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\fig1_distr_all.eps, as(eps) replace
drop Aall1-Aall5


* PLOTTING FIGURE 3b. GAP IN WORKFORCE DISTRIBUTION ACROSS EDUCATION
gen rou2=rou1
replace rou2=. in 7/12
label values rou2 rou1_lbl

* SC/ST gap, ALL
svmat Anonscst
svmat Ascst
generate Agap_rel1 = Anonscst1/Ascst1
generate Agap_rel2 = Anonscst2/Ascst2
generate Agap_rel3 = Anonscst3/Ascst3
generate Agap_rel4 = Anonscst4/Ascst4
generate Agap_rel5 = Anonscst5/Ascst5

label variable Agap_rel1 "Edu1"
label variable Agap_rel2 "Edu2"
label variable Agap_rel3 "Edu3"
label variable Agap_rel4 "Edu4"
label variable Agap_rel5 "Edu5"

graph bar (asis) Agap_rel1 Agap_rel2 Agap_rel3 Agap_rel4 Agap_rel5, over(rou2, label(labsize(medium))) ///  
		 title("Gap in workforce distribution across edu", span ) ///
		 legend(col(5) size(medium)) ///
		 saving(gap_all_rel, replace) scheme(sj)
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\fig1_gap_all_rel.eps, as(eps) replace
drop Anonscst1-Anonscst5 Ascst1-Ascst5 Agap_rel1-Agap_rel5

* -------------------------------------------------------------- 
* TABLE 3: MARGINAL EFFECT OF SC/ST DUMMY IN ORDERED PROBIT REGRESSION FOR EDUCATION CATEGORIES
* -------------------------------------------------------------- 
levelsof round, local(round)
foreach r of local round{
	eststo: oprobit gen_edu2 hh_groupSCST2 if ( overall_smplic==1 | overall_smplip==1) & round==`r' [pw=mul4], vce(robust)
	* marginal effects
*	prchange
mfx, predict(pr outcome(1))
mfx, predict(pr outcome(2))
mfx, predict(pr outcome(3))
mfx, predict(pr outcome(4))
mfx, predict(pr outcome(5))	
}

esttab using edu_oprobit_all_uncond.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

**************************************************************************************************************************
**************************************************************************************************************************
*****************				OCCUPATION			**********************************************************
**************************************************************************************************************************
**************************************************************************************************************************

* -------------------------------------------------------------- 
* FIGURE 3: OCCUPATION DISTRIBUTION
* -------------------------------------------------------------- 

**** NON-SCST
mat A = J(1,3,.)
mat Anonscst = J(1,3,.)
levelsof round, local(round)
foreach r of local round{
	proportion usual_nco68onenum3 if (overall_smplic==1|overall_smplip==1) & round==`r' & hh_groupSCST2==0
	mat A = A\e(b)*100
	mat Anonscst = Anonscst\e(b)*100
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se 
mat WORKFORCE_C_OCCU_NONSCST = A  //Distribution of work force across occupation  for YOUNG - non SCST
mat list WORKFORCE_C_OCCU_NONSCST

***** SCST
mat A = J(1,3,.)
mat Ascst = J(1,3,.)
levelsof round, local(round)
foreach r of local round{
	proportion usual_nco68onenum3 if (overall_smplic==1|overall_smplip==1) & round==`r' & hh_groupSCST2==1
	mat A = A\e(b)*100
	mat Ascst = Ascst\e(b)*100
	mat E = vecdiag(e(V))
	matmap E E, m(sqrt(@))
	mat A = A\E
}
matrix rownames A = blank 38 se 43 se 50 se 55 se 61 se  
mat WORKFORCE_C_OCCU_SCST = A  //Distribution of work force across occupation  for YOUNG - SCST
mat list WORKFORCE_C_OCCU_SCST

* PLOTTING FIGURE 3a. DISTRIBUTION OF WORKFORCE ACROSS OCCUPATIONS
* combine non-SC/STs and SC/STs
mat Aall_occ=Anonscst\Ascst
svmat Aall_occ
label variable Aall_occ1 "Occ1"
label variable Aall_occ2 "Occ2"
label variable Aall_occ3 "Occ3"


graph bar (asis) Aall_occ1 Aall_occ2 Aall_occ3, over(rou1, label(alternate labsize(medium))) over(scst_divide, label(labsize(large))) ///  
		 stack percent     ytitle(" ") ///
		 title("Distribution of workforce across occ", justification(center) ) ///
		 legend(col(3) size(medium)) ///
		 saving(distr_occ_all, replace) scheme(sj)
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\fig3_distr_occ_all.eps, as(eps) replace


* PLOTTING FIGURE 3b. GAP IN WORKFORCE DISTRIBUTION ACROSS OCCUPATIONS
mat Anonscst_occ = Anonscst
mat Ascst_occ = Ascst

svmat Anonscst_occ
svmat Ascst_occ
generate Agap_occ_rel1 = Anonscst_occ1/Ascst_occ1
generate Agap_occ_rel2 = Anonscst_occ2/Ascst_occ2
generate Agap_occ_rel3 = Anonscst_occ3/Ascst_occ3

label variable Agap_occ_rel1 "Occ1"
label variable Agap_occ_rel2 "Occ2"
label variable Agap_occ_rel3 "Occ3"

graph bar (asis) Agap_occ_rel1 Agap_occ_rel2 Agap_occ_rel3, over(rou2, label(labsize(medium))) ///  
		 title("Gap in workforce distribution across occ", span ) ///
		 legend(col(3) size(medium)) ///
		 saving(gap_occ_all_rel, replace) scheme(sj)
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\fig3_gap_occ_all_rel.eps, as(eps) replace
drop Aall_occ1-Aall_occ3 Agap_occ1-Agap_occ3 /// 
	Anonscst_occ1-Anonscst_occ3 Ascst_occ1-Ascst_occ3 Agap_occ_rel1-Agap_occ_rel3 

	
* -------------------------------------------------------------- 
* TABLE 4: MARGINAL EFFECT OF SC/ST DUMMY IN MULTINOMIAL PROBIT REGRESSIONS FOR OCCUPATIONS
* -------------------------------------------------------------- 

* ----------------------------------------------------
*		MULTINOMIAL PROBIT MODEL FOR OCCUPATION
* ----------------------------------------------------
levelsof round, local(round)
foreach r of local round{
	eststo: mprobit usual_nco68onenum3 hh_groupSCST2 if ( overall_smplic==1 | overall_smplip==1) & round==`r' [pw=mul4], baseoutcome(3) vce(robust)
	mfx, predict(pr outcome(1))
	mfx, predict(pr outcome(2))
	mfx, predict(pr outcome(3))
	}
esttab using occu_mprobit_all_simple.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

**************************************************************************************************************************
**************************************************************************************************************************
*****************				WAGES AND CONSUMPTION			**********************************************************
**************************************************************************************************************************
**************************************************************************************************************************

* -------------------------------------------------------------- 
* FIGURE 5: THE LOG WAGE DISTRIBUTIONS OF NON-SC/STS AND SC/STS FOR 1983 AND 2004-05
* -------------------------------------------------------------- 
ge lwage_usual  = ln(wage_usual)

*** PLOTTING FIGURE 5A
twoway (kdensity lwage_usual [aw=mul4] if (wage_smplip==1 | wage_smplic==1) & (lwage_usual>=0 & lwage_usual<=5) & (hh_groupSCST2==0) & round==38, lpattern(solid) lwidth(medthick)) ///  
	|| (kdensity lwage_usual [aw=mul4] if (wage_smplip==1 | wage_smplic==1) & (lwage_usual>=0 & lwage_usual<=5) & (hh_groupSCST2==1) & round==38, lpattern(dash) lwidth(medthick))  ///
	|| (kdensity lwage_usual [aw=mul4] if (wage_smplip==1 | wage_smplic==1) & (lwage_usual>=0 & lwage_usual<=5) & (hh_groupSCST2==0) & round==61, lpattern(dot) lwidth(medthick)) /// 
	|| (kdensity lwage_usual [aw=mul4] if (wage_smplip==1 | wage_smplic==1) & (lwage_usual>=0 & lwage_usual<=5) & (hh_groupSCST2==1) & round==61, lpattern(dash_dot_dot) lwidth(medthick)), /// 
	xtitle("log wage (real)") ytitle("density") ///
	legend(on order(1 "non-SCST - 1983" 2 "SCST - 1983" 3 "non-SCST - 2004-05" 4 "SCST - 2004-05")) ///
	scheme(sj) saving(lwage_density_overall, asis replace) 
graph use lwage_density_overall
graph export lwage_density_overall.eps, as(eps) replace


*** PLOTTING FIGURE 5B
levelsof round, local(round)
qui foreach r of local round{

pctile lwage_pctnon_`r'  = lwage_usual [aw=mul4] if (wage_smplip==1 | wage_smplic==1) & (lwage_usual>=0 & lwage_usual<=5) & (round==`r') & (hh_groupSCST2==0), nq(100) genp(percentw_`r')
pctile lwage_pctscst_`r' = lwage_usual [aw=mul4] if (wage_smplip==1 | wage_smplic==1) & (lwage_usual>=0 & lwage_usual<=5) & (round==`r') & (hh_groupSCST2==1), nq(100) 
}

levelsof round, local(round)
qui foreach r of local round{
generate lwage_pctdif_`r' = lwage_pctnon_`r' - lwage_pctscst_`r'
}


************************************ FIRST and LAST rounds
twoway  (line lwage_pctdif_38  percentw_38, lpattern(solid) lwidth(medthick) ) ///  
     || (line lwage_pctdif_61  percentw_61, lpattern(dash_dot) lwidth(medthick) ) ,  ///
    	xtitle("percentile") ytitle("lnwage(NonSC/ST)-lnwage(SC/ST)") title("", size(huge)) ///
	xscale(range(0 101)) xlabel(0(10)101, labs(medium)) xtic(0(10)101) ///
    	ylabel(-0.1(0.1)0.7, labs(medium)) ytic(-0.1(0.1)0.7) ///
    	legend(col(3) size(medium)) ///
    	legend(on order(1 "1983" 2 "2004-05")) ///
     	saving(percentiles-wage-38-61, replace)	scheme(sj)	
graph use percentiles-wage-38-61
graph export percentiles-wage-38-61.eps, as(eps) replace


foreach r in 38 43 50 55 61 {
		drop percentw_`r' lwage_pctnon_`r' lwage_pctscst_`r' lwage_pctdif_`r'
}	

* -------------------------------------------------------------- 
* TABLE 5: WAGE GAPS AND CHANGES
* -------------------------------------------------------------- 
** WE WILL CONTROL FOR AGE AND AGE^2
ge age2=age^2

* OLS
levelsof round if round!=43, local(round)
foreach r of local round{
eststo :	regress lwage_usual hh_groupSCST2 age age2 if (wage_smplip==1 | wage_smplic==1) & round==`r' [pw=mul4], robust
}
esttab using wage_ols_co.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

* RIF for 50th percentile
levelsof round if round!=43, local(round)
foreach r of local round{
eststo:	rifreg lwage_usual hh_groupSCST2 age age2 if (wage_smplip==1 | wage_smplic==1) & round==`r' [aw=mul4], quantile(0.5)
}
esttab using wage_rif50_co.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

* RIF for 10th percentile
levelsof round if round!=43, local(round)
foreach r of local round{
eststo:	rifreg lwage_usual hh_groupSCST2 age age2 if (wage_smplip==1 | wage_smplic==1) & round==`r' [aw=mul4], quantile(0.1)
}
esttab using wage_rif10_co.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

* RIF for 90th percentile
levelsof round if round!=43, local(round)
foreach r of local round{
eststo:	rifreg lwage_usual hh_groupSCST2 age age2 if (wage_smplip==1 | wage_smplic==1) & round==`r' [aw=mul4], quantile(0.9)
}
esttab using wage_rif90_co.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear


* -------------------------------------------------------------- 
* FIGURE 6: THE PERCENTILE WAGE GAPS: DECOMPOSITIONS
* -------------------------------------------------------------- 
*** SEQUENTIAL APPROACH
gen scst = hh_groupSCST2
generate lwage_within = 0
replace lwage_within=1 if (lwage_usual>=0 & lwage_usual<=5)

foreach r of numlist 38 61{

		**** SEQUENTIAL APPROACH TO INTRODUCING CHARACTERISTICS: region, age, etc
*probit scst age age2 sector1 zone_dum1-zone_dum5 ///
*			if (wage_smplip==1 | wage_smplic==1) & (lwage_within==1) & round==`r' [pw=mul4]

		**** SEQUENTIAL APPROACH TO INTRODUCING CHARACTERISTICS: previous+edu
*probit scst age age2 sector1 zone_dum1-zone_dum5 edu_dum2-edu_dum5 ///
*			if (wage_smplip==1 | wage_smplic==1) & (lwage_within==1) & round==`r' [pw=mul4]
			
			**** SEQUENTIAL APPROACH TO INTRODUCING CHARACTERISTICS: previous+quota
probit scst age age2 sector1 zone_dum1-zone_dum5 edu_dum2-edu_dum5 quota_scst ///
			if (wage_smplip==1 | wage_smplic==1) & (lwage_within==1) & round==`r' [pw=mul4]
			
predict double phat`r' if e(sample), p
summ scst [weight=mul4] if round==`r'
gen pbar`r'=r(mean)

gen double wgt`r'=( phat`r'/(1-phat`r') )*( (1-pbar`r')/pbar`r' )*mul4 if scst==0 & round==`r'

kdensity lwage_usual if scst==1 & (wage_smplip==1 | wage_smplic==1) & (lwage_within==1) & round==`r' [aw=mul4], n(100) gen(x_ufact`r' ufactual`r') nograph
kdensity lwage_usual if scst==0 & (wage_smplip==1 | wage_smplic==1) & (lwage_within==1) & round==`r' [aw=mul4], gen(factual`r') at(x_ufact`r') nograph
kdensity lwage_usual if scst==0 & (wage_smplip==1 | wage_smplic==1) & (lwage_within==1) & round==`r' [aw=wgt`r'], gen(cfactual`r') at(x_ufact`r') nograph

*** decomposition components:
* overall
gen diff_all`r' = factual`r'-ufactual`r'

* explained = beta_N*( X_N - X_S )
gen diff_expl`r' = factual`r' - cfactual`r'

* unexplained = ( beta_N - beta_S )*X_S
gen diff_unexpl`r' = cfactual`r' - ufactual`r'

}

********** SEQUENTIAL APPROACH RESULTS: PICK ONE LOCAL AT A TIME. NEED TO DO ALL THREE BEFORE PLOTTING THE RESULTS AS IN FIGURE 6
* sequential with just regions, age, etc
*local seq "noedu"

* sequential with just edu and regions
*local seq "edureg"

* sequential with edu, regions, quota
local seq "all"

foreach r of numlist 38 61 {
rename lwage_pctdifnon`r' lwage_pctdifnon`r'_`seq'
rename lwage_pctdifsc`r'  lwage_pctdifsc`r'_`seq'
}

drop phat38- lwage_pctdif38 lwage_pctnon61- lwage_pctdif61

************************************ round 38
twoway  (line lwage_pctdif38     		percentw38, lpattern("l") lwidth(medthick)  ms(S) msize(medium)) ///  
     || (line lwage_pctdifnon38_noedu  	percentw38, lpattern("_") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lwage_pctdifnon38_edureg  percentw38, lpattern("_..") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lwage_pctdifnon38_all  	percentw38, lpattern(".") lwidth(medthick)  ms(O) msize(medium)),   ///
    	xtitle("percentile") ytitle("lnwage(NonSC/ST)-lnwage(SC/ST)") title("Caste wage gap, 1983", size(large)) ///
		xscale(range(0 101)) xlabel(0(10)101, labs(medium)) xtic(0(10)101) ///
    	ylabel(-0.1(0.1)0.7, labs(medium)) ytic(-0.1(0.1)0.7) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "actual" 2 "explained:demogr" 3 "explained:edu" 4 "explained:quota")) ///
     	saving(percentiles-wage-38-cft_rr2, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\percentiles-wage-38-cft_rr2.eps, as(eps) replace

************************************ rounds 61
twoway  (line lwage_pctdif61     		percentw61, lpattern("l") lwidth(medthick)  ms(S) msize(medium)) ///  
     || (line lwage_pctdifnon61_noedu  	percentw61, lpattern("_") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lwage_pctdifnon61_edureg  percentw61, lpattern("_..") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lwage_pctdifnon61_all  	percentw61, lpattern(".") lwidth(medthick)  ms(O) msize(medium)),   ///
    	xtitle("percentile") ytitle("lnwage(NonSC/ST)-lnwage(SC/ST)") title("Caste wage gap, 2004-05", size(large)) ///
		xscale(range(0 101)) xlabel(0(10)101, labs(medium)) xtic(0(10)101) ///
    	ylabel(-0.1(0.1)0.7, labs(medium)) ytic(-0.1(0.1)0.7) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "actual" 2 "explained:demogr" 3 "explained:edu" 4 "explained:quota")) ///
     	saving(percentiles-wage-61-cft_rr2, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\percentiles-wage-61-cft_rr2.eps, as(eps) replace

* explained shares of wages
generate lwage_explshare38 = lwage_pctdifnon38_all/lwage_pctdif38
generate lwage_explshare61 = lwage_pctdifnon61_all/lwage_pctdif61


* -------------------------------------------------------------- 
* TABLE 6: DECOMPOSING CHANGES IN SC/ST WAGE GAPS OVER TIME
* -------------------------------------------------------------- 
* see do file 20110156-TABLES6and8.do


* -------------------------------------------------------------- 
* FIGURE 7: THE LOG CONSUMPTION DISTRIBUTIONS OF NON-SC/STS AND SC/STS FOR 1983 AND 2004-05
* -------------------------------------------------------------- 
* creating household level multiplier that reflects size of population
gen hh_mul4 = mul4*hh_size2 

* daily consumption to make it comparable with daily wages
gen lmpced = ln(mpce/30)

*** PLOTTING FIGURE 7A
twoway     (kdensity lmpced [aw=hh_mul4] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpced>=-1 & lmpced<=5) & (hh_groupSCST2==0) & round==38, lpattern(solid) lwidth(medthick)) ///  
	|| (kdensity lmpced [aw=hh_mul4] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpced>=-1 & lmpced<=5) & (hh_groupSCST2==1) & round==38, lpattern(dash) lwidth(medthick))  ///
	|| (kdensity lmpced [aw=hh_mul4] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpced>=-1 & lmpced<=5) & (hh_groupSCST2==0) & round==61, lpattern(dot) lwidth(medthick)) /// 
	|| (kdensity lmpced [aw=hh_mul4] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpced>=-1 & lmpced<=5) & (hh_groupSCST2==1) & round==61, lpattern(dash_dot_dot) lwidth(medthick)), /// 
	xtitle("log consumption (real)") ytitle("density") /// title("Consumption distribution by social groups, extended sample") ///
	legend(on order(1 "non-SCST - 1983" 2 "SCST - 1983" 3 "non-SCST - 2004-05" 4 "SCST - 2004-05")) ///
	saving(conskernel-overall, asis replace) scheme(sj)
graph export conskernel-overall.eps, as(eps) replace
	

*** PLOTTING FIGURE 7B
levelsof round, local(round)
qui foreach r of local round{

pctile lmpce_pctnon_`r'  = lmpced [aw=hh_mul4] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (round==`r') & (hh_groupSCST2==0), nq(100) genp(percent_`r')
pctile lmpce_pctscst_`r' = lmpced [aw=hh_mul4] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (round==`r') & (hh_groupSCST2==1), nq(100) 
}

levelsof round, local(round)
qui foreach r of local round{
generate lmpce_pctdif_`r' = lmpce_pctnon_`r' - lmpce_pctscst_`r'
}

************************************ FIRST and LAST rounds
twoway  (line lmpce_pctdif_38  percent_38, lpattern(solid) lwidth(thick) ) ///  
      || (line lmpce_pctdif_61  percent_61, lpattern(dash_dot) lwidth(thick) ) ,  ///
    	xtitle("percentile") ytitle("lnmpce(NonSC/ST)-lnmpce(SC/ST)") title("", size(huge)) ///
	xscale(range(0 101)) xlabel(0(10)101, labs(medium)) xtic(0(10)101) ///
    	ylabel(-0.1(0.1)0.7, labs(medium)) ytic(-0.1(0.1)0.7) ///
    	legend(col(3) size(medium)) ///
    	legend(on order(1 "1983" 2 "2004-05")) ///
     	saving(percentiles-mpced-38-61, replace)	scheme(sj)
graph use percentiles-mpced-38-61
graph export percentiles-mpced-38-61.eps, as(eps) replace


foreach r in 38 43 50 55 61 {
		drop percent_`r' lmpce_pctnon_`r' lmpce_pctscst_`r' lmpce_pctdif_`r'
}	
	

* -------------------------------------------------------------- 
* TABLE 7: CONSUMPTION GAPS AND CHANGES
* -------------------------------------------------------------- 
* creating household level multiplier that reflects size of population
gen hh_mul4 = mul4*hh_size2 

* daily consumption to make it comparable with daily wages
gen lmpced = ln(mpce/30)

tab round, gen(round)

* OLS
levelsof round, local(round)
foreach r of local round{
eststo :	regress lmpced hh_groupSCST2 if (overall_smplip==1 | overall_smplic==1) & reln_head==1 & round==`r' [pw=hh_mul4], robust
}
esttab using mpce_ols_uc.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

* RIF for 50th percentile
levelsof round, local(round)
foreach r of local round{
eststo: 	rifreg lmpced hh_groupSCST2 if (overall_smplic==1 | overall_smplip==1) & reln_head==1 & round==`r' [aw=hh_mul4], q(0.5)
}
esttab using mpce_rif50_uc.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

* RIF for 10th percentile
levelsof round, local(round)
foreach r of local round{
eststo: 	rifreg lmpced hh_groupSCST2 if (overall_smplic==1 | overall_smplip==1) & reln_head==1 & round==`r' [aw=hh_mul4], q(0.1)
}
esttab using mpce_rif10_uc.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear

* RIF for 90th percentile
levelsof round, local(round)
foreach r of local round{
eststo: 	rifreg lmpced hh_groupSCST2 if (overall_smplic==1 | overall_smplip==1) & reln_head==1 & round==`r' [aw=hh_mul4], q(0.9)
}
esttab using mpce_rif90_uc.csv, se r2 b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) compress replace
eststo clear


* -------------------------------------------------------------- 
* FIGURE 8: THE PERCENTILE CONSUMPTION GAPS: DECOMPOSITIONS
* -------------------------------------------------------------- 
* creating household level multiplier that reflects size of population
gen hh_mul4 = mul4*hh_size2 

* daily consumption to make it comparable with daily wages
gen lmpced = ln(mpce/30)

generate lmpce_within = 0
replace lmpce_within=1 if (lmpced>=-1 & lmpced<=4)

gen scst = hh_groupSCST2
	
foreach r of numlist 38 61{

* hh-level probit

		**** SEQUENTIAL APPROACH TO INTRODUCING CHARACTERISTICS: region, age, etc
*probit scst sector1 hh_size2 earning_mem zone_dum1-zone_dum5 ///
*			 if (overall_smplic==1 | overall_smplip==1) & (lmpce_within==1) & reln_head==1 & round==`r' [pw=hh_mul4]

		**** SEQUENTIAL APPROACH TO INTRODUCING CHARACTERISTICS: previous+edu
*probit scst sector1 hh_size2 earning_mem zone_dum1-zone_dum5  head_edu_dum2-head_edu_dum5 max_edu_dum2-max_edu_dum5 ///
*			 if (overall_smplic==1 | overall_smplip==1) & (lmpce_within==1) & reln_head==1 & round==`r' [pw=hh_mul4]
			
			**** SEQUENTIAL APPROACH TO INTRODUCING CHARACTERISTICS: previous+quota
probit scst sector1 hh_size2 earning_mem zone_dum1-zone_dum5  head_edu_dum2-head_edu_dum5 max_edu_dum2-max_edu_dum5 quota_scst ///
			 if (overall_smplic==1 | overall_smplip==1) & (lmpce_within==1) & reln_head==1 & round==`r' [pw=hh_mul4]

predict double phat`r' if e(sample), p


summ scst [weight=mul4] if round==`r'
gen pbar`r'=r(mean)
gen double wgt`r'=( phat`r'/(1-phat`r') )*( (1-pbar`r')/pbar`r' )*mul4 if scst==0 & round==`r'
gen double hh_wgt`r'=wgt`r'*hh_size2 if scst==0 & round==`r'

kdensity lmpced if scst==1 & (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpce_within==1) & round==`r' [aw=hh_mul4], n(100) gen(x_ufact`r' ufactual`r') nograph
kdensity lmpced if scst==0 & (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpce_within==1) & round==`r' [aw=hh_mul4], gen(factual`r') at(x_ufact`r') nograph
kdensity lmpced if scst==0 & (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpce_within==1) & round==`r' [aw=hh_wgt`r'], gen(cfactual`r') at(x_ufact`r') nograph

*** decomposition components:
* overall
gen diff_all`r' = factual`r'-ufactual`r'

* explained = beta_N*( X_N - X_S )
gen diff_expl`r' = factual`r' - cfactual`r'

* unexplained = ( beta_N - beta_S )*X_S
gen diff_unexpl`r' = cfactual`r' - ufactual`r'

}


* COMPUTE THE LOG GAPS IN MPCE FOR DIFFERENT PERCENTILES
*levelsof round, local(round)
*qui foreach r of local round{
foreach r of numlist 38 61 {

pctile lmpce_pctnon`r'  = lmpced [aw=hh_mul4]   if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpce_within==1) & (round==`r') & (hh_groupSCST2==0), nq(100) genp(percentw`r')
pctile lmpce_pctscst`r' = lmpced [aw=hh_mul4]   if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpce_within==1) & (round==`r') & (hh_groupSCST2==1), nq(100) 
pctile lmpce_pctnonc`r' = lmpced [aw=hh_wgt`r'] if (overall_smplic==1 | overall_smplip==1) & (reln_head==1) & (lmpce_within==1) & (round==`r') & (hh_groupSCST2==0), nq(100)

generate lmpce_pctdif`r' = lmpce_pctnon`r' - lmpce_pctscst`r'
generate lmpce_pctdifnon`r' = lmpce_pctnon`r' - lmpce_pctnonc`r'
generate lmpce_pctdifsc`r'  = lmpce_pctnonc`r' - lmpce_pctscst`r'

}

********** SEQUENTIAL APPROACH RESULTS
* sequential with just regions, age, etc
*local seq "noedu"

* sequential with just edu and regions
*local seq "edureg"

* sequential with edu, regions, quota
local seq "all"

foreach r of numlist 38 61 {
rename lmpce_pctdifnon`r' lmpce_pctdifnon`r'_`seq'
rename lmpce_pctdifsc`r'  lmpce_pctdifsc`r'_`seq'
}

drop phat38- lmpce_pctdif38 lmpce_pctnon61- lmpce_pctdif61

************************************ first round
twoway  (line lmpce_pctdif38     		percentw38, lpattern("l") lwidth(medthick)  ms(S) msize(medium)) ///  
     || (line lmpce_pctdifnon38_noedu  	percentw38, lpattern("_") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lmpce_pctdifnon38_edureg  percentw38, lpattern("_..") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lmpce_pctdifnon38_all  	percentw38, lpattern(".") lwidth(medthick)  ms(O) msize(medium)),   ///
    	xtitle("percentile") ytitle("lnmpce(NonSC/ST)-lnmpce(SC/ST)") title("Caste consumption gap, 1983", size(large)) ///
		xscale(range(0 101)) xlabel(0(10)101, labs(medium)) xtic(0(10)101) ///
    	ylabel(-0.1(0.1)0.7, labs(medium)) ytic(-0.1(0.1)0.7) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "actual" 2 "explained:demogr" 3 "explained:edu" 4 "explained:quota")) ///
     	saving(percentiles-mpce-38-cft_rr2, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\percentiles-mpce-38-cft_rr2.eps, as(eps) replace


************************************ fifth rounds
twoway  (line lmpce_pctdif61     		percentw61, lpattern("l") lwidth(medthick)  ms(S) msize(medium)) ///  
     || (line lmpce_pctdifnon61_noedu  	percentw61, lpattern("_") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lmpce_pctdifnon61_edureg  percentw61, lpattern("_..") lwidth(medthick)  ms(T) msize(medium))   ///
     || (line lmpce_pctdifnon61_all  	percentw61, lpattern(".") lwidth(medthick)  ms(O) msize(medium)),   ///
    	xtitle("percentile") ytitle("lnmpce(NonSC/ST)-lnmpce(SC/ST)") title("Caste consumption gap, 2004-05", size(large)) ///
		xscale(range(0 101)) xlabel(0(10)101, labs(medium)) xtic(0(10)101) ///
    	ylabel(-0.1(0.1)0.7, labs(medium)) ytic(-0.1(0.1)0.7) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "actual" 2 "explained:demogr" 3 "explained:edu" 4 "explained:quota")) ///
     	saving(percentiles-mpce-61-cft_rr2, replace)	
*graph export C:\swp55\Docs\Diss\Castes\AEJ\responses-round2\figures\percentiles-mpce-61-cft_rr2.eps, as(eps) replace


* -------------------------------------------------------------- 
* TABLE 8: DECOMPOSING CHANGES IN SC/ST CONSUMPTION EXPENDITURE GAPS OVER TIME
* -------------------------------------------------------------- 
* see do file 20110156-TABLES6and8.do


* -------------------------------------------------------------- 
* FIGURE 9: GAPS BY GENDER
* -------------------------------------------------------------- 

************** Mean edu years
mat A_M = J(1,2,.)
mat A_F = J(1,2,.)
levelsof round, local(round)
foreach r of local round{
	mean  edu_year [pw=mul4] if (overall_smplip==1 | overall_smplic==1) & round==`r' & sex==1, over(hh_groupSCST2)
	mat A_M = A_M\e(b)
	mean  edu_year [pw=mul4] if (overall_smplip==1 | overall_smplic==1) & round==`r' & sex==2, over(hh_groupSCST2)
	mat A_F = A_F\e(b)
}

svmat A_M
svmat A_F

gen edu_gap_M = A_M1/A_M2
gen edu_gap_F = A_F1/A_F2

* PLOTTING FIGURE 9A. male and female SC/ST education gaps 
mat rou = .\38\42\50\55\61
svmat rou
label define rou_lbl 38 "1983" 43 "1987-88" 50 "1993-94" 55 "1999-00" 61 "2004-05"
label values rou1 rou_lbl

twoway (scatter edu_gap_M rou1, lpattern(solid) lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter edu_gap_F rou1, lpattern(dash) lwidth(thick) c(l) ms(D) msize(large)),  ///
    	xtitle(" ") ytitle("") title("Relative education gaps", size(huge)) subtitle("") ///
	xscale(range(37 62)) xlabel(38 43 50 55 61, valuelabel labs(medium) ) ///
    	ylabel(1(1)4.5, labs(medium)) ytic(1(1)4.5) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "male" 2 "female")) ///
     	saving(edu-gap-gender, replace)
*graph export edu-gap-gender.eps, as(eps) replace


******************** Median wages
mat A_Mnon = J(1,1,.)
mat A_Mscst = J(1,1,.)
mat A_Fnon = J(1,1,.)
mat A_Fscst = J(1,1,.)

levelsof round, local(round)
foreach r of local round{
	_pctile wage_usual [pw=mul4] if (wage_smplip==1 | wage_smplic==1) & round==`r' & sex==1 & hh_groupSCST2==0, nq(2)
	mat A_Mnon = A_Mnon\r(r1)
	_pctile wage_usual [pw=mul4] if (wage_smplip==1 | wage_smplic==1) & round==`r' & sex==1 & hh_groupSCST2==1, nq(2)
	mat A_Mscst = A_Mscst\r(r1)
	
	_pctile wage_usual [pw=mul4] if (wage_smplip==1 | wage_smplic==1) & round==`r' & sex==2 & hh_groupSCST2==0, nq(2)
	mat A_Fnon = A_Fnon\r(r1)
	_pctile wage_usual [pw=mul4] if (wage_smplip==1 | wage_smplic==1) & round==`r' & sex==2 & hh_groupSCST2==1, nq(2)
	mat A_Fscst = A_Fscst\r(r1)
}
	
svmat A_Mnon
svmat A_Mscst
svmat A_Fnon
svmat A_Fscst

gen wage_gap_M = A_Mnon1/A_Mscst1
gen wage_gap_F = A_Fnon1/A_Fscst1

* PLOTTING FIGURE 9B. male and female SC/ST wage gaps 
twoway (scatter wage_gap_M rou1, lpattern(solid) lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter wage_gap_F rou1, lpattern(dash) lwidth(thick) c(l) ms(D) msize(large)),  ///
    	xtitle(" ") ytitle("") title("Median relative wage gaps", size(huge)) subtitle("") ///
	xscale(range(37 62)) xlabel(38 43 50 55 61, valuelabel labs(medium) ) ///
    	ylabel(1(0.2)1.6, labs(medium)) ytic(1(0.2)1.6) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "male" 2 "female")) ///
     	saving(wage-gap-gender, replace)
*graph export wage-gap-gender.eps, as(eps) replace

******************** labor force participation gaps
mat A_M = J(1,2,.)
mat A_F = J(1,2,.)
levelsof round, local(round)
foreach r of local round{
	mean  lab_force [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1) & round==`r' & sex==1, over(hh_groupSCST2)
	mat A_M = A_M\e(b)
	mean  lab_force [pw=mul4] if (lfp_smplip==1 | lfp_smplic==1) & round==`r' & sex==2, over(hh_groupSCST2)
	mat A_F = A_F\e(b)
}

svmat A_M
svmat A_F

gen lfp_gap_M = A_M1/A_M2
gen lfp_gap_F = A_F1/A_F2

* PLOTTING FIGURE 9C. male and female SC/ST LFP gaps 
twoway (scatter lfp_gap_M rou1, lpattern(solid) lwidth(thick) c(l) ms(S) msize(large)) ///  
    || (scatter lfp_gap_F rou1, lpattern(dash) lwidth(thick) c(l) ms(D) msize(large)),  ///
    	xtitle(" ") ytitle("") title("Relative labor force partic gaps", size(huge)) subtitle("") ///
	xscale(range(37 62)) xlabel(38 43 50 55 61, valuelabel labs(medium) ) ///
    	ylabel(0.6(0.1)1.1, labs(medium)) ytic(0.6(0.1)1.1) ///
    	legend(col(2) size(medium)) ///
    	legend(on order(1 "male" 2 "female")) ///
     	saving(lfp-gap-gender, replace)
*graph export lfp-gap-gender.eps, as(eps) replace


